package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallCareerMajor;
import org.apache.ibatis.annotations.Param;

/**
 * 职业专业关联Mapper接口
 * 
 * @author ruoyi
 * @date 2023-11-25
 */
public interface MallCareerMajorMapper 
{
    /**
     * 查询职业专业关联
     * 
     * @param linkId 职业专业关联主键
     * @return 职业专业关联
     */
    public MallCareerMajor selectMallCareerMajorByLinkId(Long linkId);

    /**
     * 查询职业专业关联
     * @param careerId 职业id
     * @return
     */
    public List<MallCareerMajor> selectMallCareerMajorByCareerId(Long careerId);

    //专业筛职业列表 带薪资
    List<MallCareerMajor> selectMallCareerMajorByMajorId(@Param("majorId") Long majorId,@Param("orderType") Long orderType);

    /**
     * 查询职业专业关联列表
     * 
     * @param mallCareerMajor 职业专业关联
     * @return 职业专业关联集合
     */
    public List<MallCareerMajor> selectMallCareerMajorList(MallCareerMajor mallCareerMajor);

    /**
     * 新增职业专业关联
     * 
     * @param mallCareerMajor 职业专业关联
     * @return 结果
     */
    public int insertMallCareerMajor(MallCareerMajor mallCareerMajor);

    /**
     * 修改职业专业关联
     * 
     * @param mallCareerMajor 职业专业关联
     * @return 结果
     */
    public int updateMallCareerMajor(MallCareerMajor mallCareerMajor);

    /**
     * 删除职业专业关联
     * 
     * @param linkId 职业专业关联主键
     * @return 结果
     */
    public int deleteMallCareerMajorByLinkId(Long linkId);

    /**
     * 批量删除职业专业关联
     * 
     * @param linkIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallCareerMajorByLinkIds(Long[] linkIds);
}
